# px4sitl

This package is to help deploy the [drone_demo](https://github.com/osrf/drone_demo) with convenient desktop launchers.

See a video demonstration here:

[![SITL from the launcher](https://i.imgur.com/XQ4RMxL.png)](https://youtu.be/glAY_lhHTW8 "Example of SITL from Launcher")



## Installation

See the [installation instructions](install.md) for how to try it out.

## Instructions

After installing it you can go to the launcher and run the applications

* Iris SITL Trainer
* Plane SITL Trainer

Or the commands are also availabe from the terminal:

 * `iris_px4sitl`
 * `plane_px4sitl`
